aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--Eigen/src/QR/CompleteOrthogonalDecomposition.h4
-rw-r--r--test/qr_colpivoting.cpp2
2 files changed, 3 insertions, 3 deletions
diff --git a/test/qr_colpivoting.cpp b/test/qr_colpivoting.cpp
index d8672ce33..46c54b74f 100644
--- a/test/qr_colpivoting.cpp
+++ b/test/qr_colpivoting.cpp
@@ -58,7 +58,7 @@ void cod() {
MatrixType svd_solution = svd.solve(rhs);
VERIFY_IS_APPROX(cod_solution, svd_solution);
- MatrixType pinv = cod.inverse();
+ MatrixType pinv = cod.pseudoInverse();
VERIFY_IS_APPROX(cod_solution, pinv * rhs);
}
diff --git a/Eigen/src/QR/CompleteOrthogonalDecomposition.h b/Eigen/src/QR/CompleteOrthogonalDecomposition.h
index 9bc768b7c..e71944fd7 100644
--- a/Eigen/src/QR/CompleteOrthogonalDecomposition.h
+++ b/Eigen/src/QR/CompleteOrthogonalDecomposition.h
@@ -249,10 +249,10 @@ class CompleteOrthogonalDecomposition {
/** \returns the pseudo-inverse of the matrix of which *this is the complete
* orthogonal decomposition.
* \warning: Do not compute \c this->inverse()*rhs to solve a linear systems.
* It is more efficient and numerically stable to call \c this->solve(rhs).
*/
- inline const Inverse<CompleteOrthogonalDecomposition> inverse() const
+ inline const Inverse<CompleteOrthogonalDecomposition> pseudoInverse() const
{
return Inverse<CompleteOrthogonalDecomposition>(*this);
}
@@ -249,10 +249,10 @@ class CompleteOrthogonalDecomposition {
/** \returns the pseudo-inverse of the matrix of which *this is the complete
* orthogonal decomposition.
- * \warning: Do not compute \c this->inverse()*rhs to solve a linear systems.
+ * \warning: Do not compute \c this->pseudoInverse()*rhs to solve a linear systems.
* It is more efficient and numerically stable to call \c this->solve(rhs).
*/